/*
 *  armadillo2x0_sw.c
 *
 *  Copyright (C) 2006,2009 Atmark Techno, Inc.
 */
#include <linux/module.h>
#include <linux/types.h>
#include <linux/kernel.h>
#include <linux/miscdevice.h>
#include <linux/init.h>
#include <linux/ioport.h>
#include <linux/sched.h>
#include <linux/fs.h>
#include <linux/file.h>
#include <linux/poll.h>
#include <linux/irq.h>
#include <asm/uaccess.h>
#include <asm/hardware.h>
#include <asm/io.h>

#include <asm/arch/armadillo2x0_sw.h>

#ifndef SW_MINOR
#define SW_MINOR (187)
#endif
#define SW_NAME "sw"

#define AUTHOR      "Atmark Techno, Inc."
#define DESCRIPTION "Armadillo-2x0 Takt Switch driver"
#define LICENSE     "GPL v2"

#define VERSION     SW_NAME ": " DESCRIPTION ", (C) 2006,2009 " AUTHOR

#define GPIO_F_SW_BIT (1 << 7)

static DECLARE_WAIT_QUEUE_HEAD(sw_wait);
static volatile int reset = 1;

static ssize_t armadillo2x0_sw_read (struct file *file, char __user *buf,
				     size_t count, loff_t *ppos)
{
	char val = !!(inl(EP93XX_GPIO_F_DATA) & GPIO_F_SW_BIT);

	reset = 1;

	if (copy_to_user(buf, &val, 1))
		return -EFAULT;

        return 1;
}

static int armadillo2x0_sw_open(struct inode *inode, struct file *file)
{
	unsigned int minor = MINOR(inode->i_rdev); 

	if (minor != SW_MINOR)
		return -ENODEV;

#ifdef MODULE
	//MOD_INC_USE_COUNT;
#endif

	return 0;
}

static int armadillo2x0_sw_release(struct inode *inode, struct file *file)
{

#ifdef MODULE
	//MOD_DEC_USE_COUNT;
#endif

	return 0;
}

static void armadillo2x0_sw_interrupt_ack(unsigned int irq, struct irq_desc *desc)
{
	unsigned long ulTemp;

	if (!(inl(EP93XX_GPIO_F_INT_STATUS) & GPIO_F_SW_BIT))
		return;

	outl(GPIO_F_SW_BIT, EP93XX_GPIO_F_INT_ACK);
	ulTemp = inl(EP93XX_GPIO_F_INT_ACK);

	reset = 0;
	if (waitqueue_active(&sw_wait))
		wake_up_interruptible(&sw_wait);
}

static int armadillo2x0_sw_ioctl(struct inode *inode, struct file *file,
				 unsigned int cmd, unsigned long arg)
{
	switch (cmd) {
	case ARMADILLO2X0_SW_REQUEST_IRQ:
		set_irq_flags(IRQ_EP93XX_GPIO7MUX, IRQF_VALID | IRQF_PROBE);

		break;
	case ARMADILLO2X0_SW_FREE_IRQ:
		set_irq_flags(IRQ_EP93XX_GPIO7MUX, 0);

		break;
	default:
		return -ENOIOCTLCMD;
	}

	return 0;
}

static unsigned int armadillo2x0_sw_poll(struct file *file, poll_table *wait)
{
	poll_wait(file, &sw_wait, wait);
	if (!reset)
		return POLLIN | POLLRDNORM;

	return 0;
}

static struct file_operations armadillo2x0_sw_fops = {
	owner:		THIS_MODULE,
	read:		armadillo2x0_sw_read,
	poll:		armadillo2x0_sw_poll,
	ioctl:		armadillo2x0_sw_ioctl,
	open:		armadillo2x0_sw_open,
	release:	armadillo2x0_sw_release,
};

static struct miscdevice armadillo2x0_sw_miscdev = {
	SW_MINOR,
	SW_NAME,
	&armadillo2x0_sw_fops
};

int __init armadillo2x0_sw_init(void)
{
	outl(inl(EP93XX_GPIO_F_DIRECTION) & ~GPIO_F_SW_BIT, EP93XX_GPIO_F_DIRECTION);
	outl(inl(EP93XX_GPIO_F_INT_TYPE1) | GPIO_F_SW_BIT, EP93XX_GPIO_F_INT_TYPE1);
	outl(inl(EP93XX_GPIO_F_INT_TYPE2) & ~GPIO_F_SW_BIT, EP93XX_GPIO_F_INT_TYPE2);
	outl(inl(EP93XX_GPIO_F_DEBOUNCE) | GPIO_F_SW_BIT, EP93XX_GPIO_F_DEBOUNCE);
	outl(inl(EP93XX_GPIO_F_INT_ENABLE) | GPIO_F_SW_BIT, EP93XX_GPIO_F_INT_ENABLE);

	misc_register(&armadillo2x0_sw_miscdev);

	set_irq_handler(IRQ_EP93XX_GPIO7MUX, armadillo2x0_sw_interrupt_ack);

	printk(KERN_INFO VERSION "\n");

	return 0;
}	

void __exit armadillo2x0_sw_exit(void)
{
	set_irq_handler(IRQ_EP93XX_GPIO7MUX, NULL);

	misc_deregister(&armadillo2x0_sw_miscdev);

	outl(inl(EP93XX_GPIO_F_INT_ENABLE) & ~GPIO_F_SW_BIT, EP93XX_GPIO_F_INT_ENABLE);
}

module_init(armadillo2x0_sw_init);
module_exit(armadillo2x0_sw_exit);

MODULE_AUTHOR(AUTHOR);
MODULE_DESCRIPTION(DESCRIPTION);
MODULE_LICENSE(LICENSE);
