/*
 * linux/include/asm-arm/arch-ep93xx/ep93xx-regs.h
 */

#ifndef __ASM_ARCH_EP93XX_REGS_H
#define __ASM_ARCH_EP93XX_REGS_H

/*
 * EP93xx linux memory map:
 *
 * virt		phys		size
 * fe800000			5M		per-platform mappings
 * fed00000	80800000	2M		APB
 * fef00000	80000000	1M		AHB
 */

#define EP93XX_AHB_PHYS_BASE		0x80000000
#define EP93XX_AHB_VIRT_BASE		0xfef00000
#define EP93XX_AHB_SIZE			0x00100000

#define EP93XX_APB_PHYS_BASE		0x80800000
#define EP93XX_APB_VIRT_BASE		0xfed00000
#define EP93XX_APB_SIZE			0x00200000


/* AHB peripherals */
#define EP93XX_DMA_BASE			(EP93XX_AHB_VIRT_BASE + 0x00000000)

#define EP93XX_ETHERNET_BASE		(EP93XX_AHB_VIRT_BASE + 0x00010000)
#define EP93XX_ETHERNET_PHYS_BASE	(EP93XX_AHB_PHYS_BASE + 0x00010000)

#define EP93XX_USB_BASE			(EP93XX_AHB_VIRT_BASE + 0x00020000)
#define EP93XX_USB_PHYS_BASE		(EP93XX_AHB_PHYS_BASE + 0x00020000)

#define EP93XX_RASTER_BASE		(EP93XX_AHB_VIRT_BASE + 0x00030000)
#define EP93XX_RASTER_PHYS_BASE		(EP93XX_AHB_PHYS_BASE + 0x00030000)
#define EP93XX_RASTER_REG(x)		(EP93XX_RASTER_BASE + (x))
#define EP93XX_RASTER_VLINESTOTAL	EP93XX_RASTER_REG(0x00)
#define EP93XX_RASTER_VSYNCSTRTSTOP	EP93XX_RASTER_REG(0x04)
#define EP93XX_RASTER_VACTIVESTRTSTOP	EP93XX_RASTER_REG(0x08)
#define EP93XX_RASTER_VCLKSTRTSTOP	EP93XX_RASTER_REG(0x0C)
#define EP93XX_RASTER_HCLKSTOTAL	EP93XX_RASTER_REG(0x10)
#define EP93XX_RASTER_HSYNCSTRTSTOP	EP93XX_RASTER_REG(0x14)
#define EP93XX_RASTER_HACTIVESTRTSTOP	EP93XX_RASTER_REG(0x18)
#define EP93XX_RASTER_HCLKSTRTSTOP	EP93XX_RASTER_REG(0x1C)
#define EP93XX_RASTER_BRIGHTNESS	EP93XX_RASTER_REG(0x20)
#define EP93XX_RASTER_VIDEOATTRIBS	EP93XX_RASTER_REG(0x24)
#define EP93XX_RASTER_VIDEOATTRIBS_EN			(1<<0)
#define EP93XX_RASTER_VIDEOATTRIBS_PCLKEN		(1<<1)
#define EP93XX_RASTER_VIDEOATTRIBS_SYNCEN		(1<<2)
#define EP93XX_RASTER_VIDEOATTRIBS_DATAEN		(1<<3)
#define EP93XX_RASTER_VIDEOATTRIBS_CSYNC		(1<<4)
#define EP93XX_RASTER_VIDEOATTRIBS_VCPOL		(1<<5)
#define EP93XX_RASTER_VIDEOATTRIBS_HSPOL		(1<<6)
#define EP93XX_RASTER_VIDEOATTRIBS_BLKPOL		(1<<7)
#define EP93XX_RASTER_VIDEOATTRIBS_INVCLK		(1<<8)
#define EP93XX_RASTER_VIDEOATTRIBS_ACEN			(1<<9)
#define EP93XX_RASTER_VIDEOATTRIBS_LCDEN		(1<<10)
#define EP93XX_RASTER_VIDEOATTRIBS_CCIREN		(1<<12)
#define EP93XX_RASTER_VIDEOATTRIBS_PIFEN		(1<<13)
#define EP93XX_RASTER_VIDEOATTRIBS_INTEN		(1<<14)
#define EP93XX_RASTER_VIDEOATTRIBS_INT			(1<<15)
#define EP93XX_RASTER_VIDEOATTRIBS_INTRLC		(1<<16)
#define EP93XX_RASTER_VIDEOATTRIBS_EQUSER		(1<<17)
#define EP93XX_RASTER_VIDEOATTRIBS_DHORZ		(1<<18)
#define EP93XX_RASTER_VIDEOATTRIBS_DVERT		(1<<19)
#define EP93XX_RASTER_VIDEOATTRIBS_BKPXD		(1<<20)
#define EP93XX_RASTER_VIDEOATTRIBS_SDSEL_MASK		(0x00600000)
#define EP93XX_RASTER_VIDSCRNPAGE	EP93XX_RASTER_REG(0x28)
#define EP93XX_RASTER_VIDSCRNHPG	EP93XX_RASTER_REG(0x2C)
#define EP93XX_RASTER_SCRNLINES		EP93XX_RASTER_REG(0x30)
#define EP93XX_RASTER_LINELENGTH	EP93XX_RASTER_REG(0x34)
#define EP93XX_RASTER_VLINESTEP		EP93XX_RASTER_REG(0x38)
#define EP93XX_RASTER_LINECARRY		EP93XX_RASTER_REG(0x3C)
#define EP93XX_RASTER_BLINKRATE		EP93XX_RASTER_REG(0x40)
#define EP93XX_RASTER_BLINKMASK		EP93XX_RASTER_REG(0x44)
#define EP93XX_RASTER_BLINKPATTRN	EP93XX_RASTER_REG(0x48)
#define EP93XX_RASTER_PATTRNMASK	EP93XX_RASTER_REG(0x4C)
#define EP93XX_RASTER_BG_OFFSET		EP93XX_RASTER_REG(0x50)
#define EP93XX_RASTER_PIXELMODE		EP93XX_RASTER_REG(0x54)
#define EP93XX_RASTER_PIXELMODE_P_MASK			0x00000007
#define EP93XX_RASTER_PIXELMODE_P_MUX_DISABLE		0x00000000            
#define EP93XX_RASTER_PIXELMODE_P_4BPP			0x00000001            
#define EP93XX_RASTER_PIXELMODE_P_8BPP			0x00000002            
#define EP93XX_RASTER_PIXELMODE_P_16BPP			0x00000004            
#define EP93XX_RASTER_PIXELMODE_P_24BPP			0x00000006            
#define EP93XX_RASTER_PIXELMODE_P_32BPP			0x00000007            
#define EP93XX_RASTER_PIXELMODE_S_MASK			0x00000038
#define EP93XX_RASTER_PIXELMODE_S_1PPC			0x00000000
#define EP93XX_RASTER_PIXELMODE_S_1PPCMAPPED		0x00000008
#define EP93XX_RASTER_PIXELMODE_S_2PPC			0x00000010
#define EP93XX_RASTER_PIXELMODE_S_4PPC			0x00000018
#define EP93XX_RASTER_PIXELMODE_S_8PPC			0x00000020
#define EP93XX_RASTER_PIXELMODE_S_223PPC		0x00000028
#define EP93XX_RASTER_PIXELMODE_S_DS223PPC		0x00000030
#define EP93XX_RASTER_PIXELMODE_S_UNDEF			0x00000038
#define EP93XX_RASTER_PIXELMODE_M_MASK			0x000003c0
#define EP93XX_RASTER_PIXELMODE_M_NOBLINK		0x00000000
#define EP93XX_RASTER_PIXELMODE_M_ANDBLINK		0x00000040
#define EP93XX_RASTER_PIXELMODE_M_ORBLINK		0x00000080
#define EP93XX_RASTER_PIXELMODE_M_XORBLINK		0x000000c0
#define EP93XX_RASTER_PIXELMODE_M_BGBLINK		0x00000100
#define EP93XX_RASTER_PIXELMODE_M_OFFSINGBLINK		0x00000140
#define EP93XX_RASTER_PIXELMODE_M_OFF888BLINK		0x00000180
#define EP93XX_RASTER_PIXELMODE_M_DIMBLINK		0x00000300
#define EP93XX_RASTER_PIXELMODE_M_BRTBLINK		0x00000340
#define EP93XX_RASTER_PIXELMODE_M_DIM888BLINK		0x00000380
#define EP93XX_RASTER_PIXELMODE_M_BRT888BLINK		0x000003c0
#define EP93XX_RASTER_PIXELMODE_C_MASK			0x00003c00
#define EP93XX_RASTER_PIXELMODE_C_LUT			0x00000000
#define EP93XX_RASTER_PIXELMODE_C_888			0x00001000
#define EP93XX_RASTER_PIXELMODE_C_565			0x00001400
#define EP93XX_RASTER_PIXELMODE_C_555			0x00001800
#define EP93XX_RASTER_PIXELMODE_C_GSLUT			0x00002000
#define EP93XX_RASTER_PIXELMODE_DSCAN			0x00004000
#define EP93XX_RASTER_PIXELMODE_TRBSW			0x00008000


#define EP93XX_RASTER_PARLLIFOUT	EP93XX_RASTER_REG(0x58)
#define EP93XX_RASTER_PARLLIFIN		EP93XX_RASTER_REG(0x5C)
#define EP93XX_RASTER_CURSOR_ADR_START	EP93XX_RASTER_REG(0x60)
#define EP93XX_RASTER_CURSOR_ADR_RESET	EP93XX_RASTER_REG(0x64)
#define EP93XX_RASTER_CURSORSIZE	EP93XX_RASTER_REG(0x68)
#define EP93XX_RASTER_CURSORCOLOR1	EP93XX_RASTER_REG(0x6C)
#define EP93XX_RASTER_CURSORCOLOR2	EP93XX_RASTER_REG(0x70)
#define EP93XX_RASTER_CURSORXYLOC	EP93XX_RASTER_REG(0x74)
#define EP93XX_RASTER_CURSORXYLOC_CEN			(1<<15)
#define EP93XX_RASTER_CURSOR_DHSCAN_LH_YLOC	EP93XX_RASTER_REG(0x78)
#define EP93XX_RASTER_RASTER_SWLOCK	EP93XX_RASTER_REG(0x7C)
#define EP93XX_RASTER_GS_LUT		EP93XX_RASTER_REG(0x80)
#define EP93XX_RASTER_RASTER_TCR	EP93XX_RASTER_REG(0x100)
#define EP93XX_RASTER_RASTER_TISRA	EP93XX_RASTER_REG(0x104)
#define EP93XX_RASTER_RASTER_TISRB	EP93XX_RASTER_REG(0x108)
#define EP93XX_RASTER_CURSOR_TISR	EP93XX_RASTER_REG(0x10C)
#define EP93XX_RASTER_RASTER_TOCRA	EP93XX_RASTER_REG(0x110)
#define EP93XX_RASTER_RASTER_TOCRB	EP93XX_RASTER_REG(0x114)
#define EP93XX_RASTER_FIFO_TOCRA	EP93XX_RASTER_REG(0x118)
#define EP93XX_RASTER_FIFO_TOCRB	EP93XX_RASTER_REG(0x11C)
#define EP93XX_RASTER_BLINK_TISR	EP93XX_RASTER_REG(0x120)
#define EP93XX_RASTER_DAC_TISRA		EP93XX_RASTER_REG(0x124)
#define EP93XX_RASTER_DAC_TISRB		EP93XX_RASTER_REG(0x128)
#define EP93XX_RASTER_SHIFT_TISR	EP93XX_RASTER_REG(0x12C)
#define EP93XX_RASTER_DACMUX_TOCRA	EP93XX_RASTER_REG(0x130)
#define EP93XX_RASTER_DACMUX_TOCRB	EP93XX_RASTER_REG(0x134)
#define EP93XX_RASTER_PELMUX_TOCR	EP93XX_RASTER_REG(0x138)
#define EP93XX_RASTER_VIDEO_TOCRA	EP93XX_RASTER_REG(0x13C)
#define EP93XX_RASTER_VIDEO_TOCRB	EP93XX_RASTER_REG(0x140)
#define EP93XX_RASTER_YCRCB_TOCR	EP93XX_RASTER_REG(0x144)
#define EP93XX_RASTER_CURSOR_TOCR	EP93XX_RASTER_REG(0x148)
#define EP93XX_RASTER_VIDEO_TOCRC	EP93XX_RASTER_REG(0x14C)
#define EP93XX_RASTER_SHIFT_TOCR	EP93XX_RASTER_REG(0x150)
#define EP93XX_RASTER_BLINK_TOCR	EP93XX_RASTER_REG(0x154)
#define EP93XX_RASTER_RASTER_TCER	EP93XX_RASTER_REG(0x180)
#define EP93XX_RASTER_SIGVAL		EP93XX_RASTER_REG(0x200)
#define EP93XX_RASTER_SIGCTL		EP93XX_RASTER_REG(0x204)
#define EP93XX_RASTER_VSIGSTRTSTOP	EP93XX_RASTER_REG(0x208)
#define EP93XX_RASTER_HSIGSTRTSTOP	EP93XX_RASTER_REG(0x20C)
#define EP93XX_RASTER_SIGCLR		EP93XX_RASTER_REG(0x210)
#define EP93XX_RASTER_ACRATE		EP93XX_RASTER_REG(0x214)
#define EP93XX_RASTER_LUTCONT		EP93XX_RASTER_REG(0x218)
#define EP93XX_RASTER_LUTCONT_SWTCH			(1<<0)
#define EP93XX_RASTER_LUTCONT_STAT			(1<<1)
#define EP93XX_RASTER_VBLANKSTRTSTOP	EP93XX_RASTER_REG(0x228)
#define EP93XX_RASTER_HBLANKSTRTSTOP	EP93XX_RASTER_REG(0x22C)
#define EP93XX_RASTER_LUT		EP93XX_RASTER_REG(0x400)
#define EP93XX_RASTER_CURSORBLINK1	EP93XX_RASTER_REG(0x21C)
#define EP93XX_RASTER_CURSORBLINK2	EP93XX_RASTER_REG(0x220)
#define EP93XX_RASTER_CURSORBLINK	EP93XX_RASTER_REG(0x224)
#define EP93XX_RASTER_CURSORBLINK_EN			(1<<8)

#define EP93XX_RASTER_EOLOFFSET		EP93XX_RASTER_REG(0x230)
#define EP93XX_RASTER_FIFOLEVEL		EP93XX_RASTER_REG(0x234)
#define EP93XX_RASTER_GS_LUT2i		EP93XX_RASTER_REG(0x280)
#define EP93XX_RASTER_GS_LUT3		EP93XX_RASTER_REG(0x300)
#define EP93XX_RASTER_COLOR_LUT		EP93XX_RASTER_REG(0x400)

#define EP93XX_GRAPHICS_ACCEL_BASE	(EP93XX_AHB_VIRT_BASE + 0x00040000)
#define EP93XX_GRAPHICS_ACCEL_REG(x)		(EP93XX_GRAPHICS_ACCEL_BASE + (x))
#define EP93XX_GRAPHICS_ACCEL_SRCPIXELSTRT	EP93XX_GRAPHICS_ACCEL_REG(0x00)
#define EP93XX_GRAPHICS_ACCEL_DESTPIXELSTRT	EP93XX_GRAPHICS_ACCEL_REG(0x04)
#define EP93XX_GRAPHICS_ACCEL_BLKSRCSTRT	EP93XX_GRAPHICS_ACCEL_REG(0x08)
#define EP93XX_GRAPHICS_ACCEL_BLKDSTSTRT	EP93XX_GRAPHICS_ACCEL_REG(0x0C)
#define EP93XX_GRAPHICS_ACCEL_BLKSRCWIDTH	EP93XX_GRAPHICS_ACCEL_REG(0x10)
#define EP93XX_GRAPHICS_ACCEL_SRCLINELENGTH	EP93XX_GRAPHICS_ACCEL_REG(0x14)
#define EP93XX_GRAPHICS_ACCEL_BLKDESTWIDTH	EP93XX_GRAPHICS_ACCEL_REG(0x18)
#define EP93XX_GRAPHICS_ACCEL_BLKDESTHEIGHT	EP93XX_GRAPHICS_ACCEL_REG(0x1C)
#define EP93XX_GRAPHICS_ACCEL_DESTLINELENGTH	EP93XX_GRAPHICS_ACCEL_REG(0x20)
#define EP93XX_GRAPHICS_ACCEL_BLOCKCTRL		EP93XX_GRAPHICS_ACCEL_REG(0x24)

#define EP93XX_GRAPHICS_ACCEL_TRANSPATTRN	EP93XX_GRAPHICS_ACCEL_REG(0x28)
#define EP93XX_GRAPHICS_ACCEL_BLOCKMASK		EP93XX_GRAPHICS_ACCEL_REG(0x2C)
#define EP93XX_GRAPHICS_ACCEL_BACKGROUND	EP93XX_GRAPHICS_ACCEL_REG(0x30)
#define EP93XX_GRAPHICS_ACCEL_LINEINC		EP93XX_GRAPHICS_ACCEL_REG(0x34)
#define EP93XX_GRAPHICS_ACCEL_LINEINIT		EP93XX_GRAPHICS_ACCEL_REG(0x38)
#define EP93XX_GRAPHICS_ACCEL_LINEPATTRN	EP93XX_GRAPHICS_ACCEL_REG(0x3C)

#define EP93XX_SDRAM_CONTROLLER_BASE	(EP93XX_AHB_VIRT_BASE + 0x00060000)

#define EP93XX_PCMCIA_CONTROLLER_BASE	(EP93XX_AHB_VIRT_BASE + 0x00080000)

#define EP93XX_BOOT_ROM_BASE		(EP93XX_AHB_VIRT_BASE + 0x00090000)

#define EP93XX_IDE_BASE			(EP93XX_AHB_VIRT_BASE + 0x000a0000)

#define EP93XX_VIC1_BASE		(EP93XX_AHB_VIRT_BASE + 0x000b0000)

#define EP93XX_VIC2_BASE		(EP93XX_AHB_VIRT_BASE + 0x000c0000)


/* APB peripherals */
#define EP93XX_TIMER_BASE		(EP93XX_APB_VIRT_BASE + 0x00010000)
#define EP93XX_TIMER_REG(x)		(EP93XX_TIMER_BASE + (x))
#define EP93XX_TIMER1_LOAD		EP93XX_TIMER_REG(0x00)
#define EP93XX_TIMER1_VALUE		EP93XX_TIMER_REG(0x04)
#define EP93XX_TIMER1_CONTROL		EP93XX_TIMER_REG(0x08)
#define EP93XX_TIMER1_CLEAR		EP93XX_TIMER_REG(0x0c)
#define EP93XX_TIMER2_LOAD		EP93XX_TIMER_REG(0x20)
#define EP93XX_TIMER2_VALUE		EP93XX_TIMER_REG(0x24)
#define EP93XX_TIMER2_CONTROL		EP93XX_TIMER_REG(0x28)
#define EP93XX_TIMER2_CLEAR		EP93XX_TIMER_REG(0x2c)
#define EP93XX_TIMER4_VALUE_LOW		EP93XX_TIMER_REG(0x60)
#define EP93XX_TIMER4_VALUE_HIGH	EP93XX_TIMER_REG(0x64)
#define EP93XX_TIMER3_LOAD		EP93XX_TIMER_REG(0x80)
#define EP93XX_TIMER3_VALUE		EP93XX_TIMER_REG(0x84)
#define EP93XX_TIMER3_CONTROL		EP93XX_TIMER_REG(0x88)
#define EP93XX_TIMER3_CLEAR		EP93XX_TIMER_REG(0x8c)

#define EP93XX_I2S_BASE			(EP93XX_APB_VIRT_BASE + 0x00020000)

#define EP93XX_SECURITY_BASE		(EP93XX_APB_VIRT_BASE + 0x00030000)

#define EP93XX_GPIO_BASE		(EP93XX_APB_VIRT_BASE + 0x00040000)
#define EP93XX_GPIO_REG(x)		(EP93XX_GPIO_BASE + (x))
#define EP93XX_GPIO_A_DATA		EP93XX_GPIO_REG(0x00)
#define EP93XX_GPIO_B_DATA		EP93XX_GPIO_REG(0x04)
#define EP93XX_GPIO_C_DATA		EP93XX_GPIO_REG(0x08)
#define EP93XX_GPIO_D_DATA		EP93XX_GPIO_REG(0x0c)
#define EP93XX_GPIO_A_DIRECTION		EP93XX_GPIO_REG(0x10)
#define EP93XX_GPIO_B_DIRECTION		EP93XX_GPIO_REG(0x14)
#define EP93XX_GPIO_C_DIRECTION		EP93XX_GPIO_REG(0x18)
#define EP93XX_GPIO_D_DIRECTION		EP93XX_GPIO_REG(0x1c)
#define EP93XX_GPIO_E_DATA		EP93XX_GPIO_REG(0x20)
#define EP93XX_GPIO_E_DIRECTION		EP93XX_GPIO_REG(0x24)
#define EP93XX_GPIO_F_DATA		EP93XX_GPIO_REG(0x30)
#define EP93XX_GPIO_F_DIRECTION		EP93XX_GPIO_REG(0x34)
#define EP93XX_GPIO_G_DATA		EP93XX_GPIO_REG(0x38)
#define EP93XX_GPIO_G_DIRECTION		EP93XX_GPIO_REG(0x3C)
#define EP93XX_GPIO_H_DATA		EP93XX_GPIO_REG(0x40)
#define EP93XX_GPIO_H_DIRECTION		EP93XX_GPIO_REG(0x44)
#define EP93XX_GPIO_F_INT_TYPE1		EP93XX_GPIO_REG(0x4c)
#define EP93XX_GPIO_F_INT_TYPE2		EP93XX_GPIO_REG(0x50)
#define EP93XX_GPIO_F_INT_ACK		EP93XX_GPIO_REG(0x54)
#define EP93XX_GPIO_F_INT_ENABLE	EP93XX_GPIO_REG(0x58)
#define EP93XX_GPIO_F_INT_STATUS	EP93XX_GPIO_REG(0x5c)
#define EP93XX_GPIO_F_RAW_INT_STATUS	EP93XX_GPIO_REG(0x60)
#define EP93XX_GPIO_F_DEBOUNCE		EP93XX_GPIO_REG(0x64)
#define EP93XX_GPIO_A_INT_TYPE1		EP93XX_GPIO_REG(0x90)
#define EP93XX_GPIO_A_INT_TYPE2		EP93XX_GPIO_REG(0x94)
#define EP93XX_GPIO_A_INT_ACK		EP93XX_GPIO_REG(0x98)
#define EP93XX_GPIO_A_INT_ENABLE	EP93XX_GPIO_REG(0x9c)
#define EP93XX_GPIO_A_INT_STATUS	EP93XX_GPIO_REG(0xa0)
#define EP93XX_GPIO_A_RAW_INT_STATUS	EP93XX_GPIO_REG(0xa4)
#define EP93XX_GPIO_A_DEBOUNCE		EP93XX_GPIO_REG(0xa8)
#define EP93XX_GPIO_B_INT_TYPE1		EP93XX_GPIO_REG(0xac)
#define EP93XX_GPIO_B_INT_TYPE2		EP93XX_GPIO_REG(0xb0)
#define EP93XX_GPIO_B_INT_ACK		EP93XX_GPIO_REG(0xb4)
#define EP93XX_GPIO_B_INT_ENABLE	EP93XX_GPIO_REG(0xb8)
#define EP93XX_GPIO_B_INT_STATUS	EP93XX_GPIO_REG(0xbc)
#define EP93XX_GPIO_B_RAW_INT_STATUS	EP93XX_GPIO_REG(0xc0)
#define EP93XX_GPIO_B_DEBOUNCE		EP93XX_GPIO_REG(0xc4)
#define EP93XX_GPIO_G_EEPROM_DRIVE	EP93XX_GPIO_REG(0xc8)
#define EP93XX_GPIO_G_EEPROM_DRIVE_DATOD		(1<<1)
#define EP93XX_GPIO_G_EEPROM_DRIVE_CLKOD		(1<<0)


#define EP93XX_AAC_BASE			(EP93XX_APB_VIRT_BASE + 0x00080000)

#define EP93XX_SPI_BASE			(EP93XX_APB_VIRT_BASE + 0x000a0000)

#define EP93XX_IRDA_BASE		(EP93XX_APB_VIRT_BASE + 0x000b0000)

#define EP93XX_UART1_BASE		(EP93XX_APB_VIRT_BASE + 0x000c0000)
#define EP93XX_UART1_PHYS_BASE		(EP93XX_APB_PHYS_BASE + 0x000c0000)

#define EP93XX_UART2_BASE		(EP93XX_APB_VIRT_BASE + 0x000d0000)
#define EP93XX_UART2_PHYS_BASE		(EP93XX_APB_PHYS_BASE + 0x000d0000)

#define EP93XX_UART3_BASE		(EP93XX_APB_VIRT_BASE + 0x000e0000)
#define EP93XX_UART3_PHYS_BASE		(EP93XX_APB_PHYS_BASE + 0x000e0000)

#define EP93XX_KEY_MATRIX_BASE		(EP93XX_APB_VIRT_BASE + 0x000f0000)

#define EP93XX_ADC_BASE			(EP93XX_APB_VIRT_BASE + 0x00100000)
#define EP93XX_TOUCHSCREEN_BASE		(EP93XX_APB_VIRT_BASE + 0x00100000)

#define EP93XX_PWM_BASE			(EP93XX_APB_VIRT_BASE + 0x00110000)

#define EP93XX_RTC_BASE			(EP93XX_APB_VIRT_BASE + 0x00120000)

#define EP93XX_SYSCON_BASE		(EP93XX_APB_VIRT_BASE + 0x00130000)
#define EP93XX_SYSCON_REG(x)		(EP93XX_SYSCON_BASE + (x))
#define EP93XX_SYSCON_POWER_STATE	EP93XX_SYSCON_REG(0x00)
#define EP93XX_SYSCON_CLOCK_CONTROL	EP93XX_SYSCON_REG(0x04)
#define EP93XX_SYSCON_CLOCK_UARTBAUD	0x20000000
#define EP93XX_SYSCON_CLOCK_USH_EN	0x10000000
#define EP93XX_SYSCON_HALT		EP93XX_SYSCON_REG(0x08)
#define EP93XX_SYSCON_STANDBY		EP93XX_SYSCON_REG(0x0c)
#define EP93XX_SYSCON_CLOCK_SET1	EP93XX_SYSCON_REG(0x20)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_X2IPD_SHIFT	(0)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_X2IPD_MASK	(0x0000001f)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_X2FBD2_SHIFT	(5)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_X2FBD2_MASK	(0x000007e0)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_X1FBD1_SHIFT	(11)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_X1FBD1_MASK	(0x0000f800)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_PS_SHIFT		(16)
#define EP93XX_SYSCON_CLOCK_SET1_PLL1_PS_MASK		(0x00030000)
#define EP93XX_SYSCON_CLOCK_SET1_PCLKDIV_SHIFT		(18)
#define EP93XX_SYSCON_CLOCK_SET1_PCLKDIV_MASK		(0x000c0000)
#define EP93XX_SYSCON_CLOCK_SET1_HCLKDIV_SHIFT		(20)
#define EP93XX_SYSCON_CLOCK_SET1_HCLKDIV_MASK		(0x00700000)
#define EP93XX_SYSCON_CLOCK_SET1_nBYP1			(0x00800000)
#define EP93XX_SYSCON_CLOCK_SET1_SMCROM			(0x01000000)
#define EP93XX_SYSCON_CLOCK_SET1_FCLKDIV_SHIFT		(25)
#define EP93XX_SYSCON_CLOCK_SET1_FCLKDIV_MASK		(0x0e000000)
#define EP93XX_SYSCON_CLOCK_SET2	EP93XX_SYSCON_REG(0x24)
#define EP93XX_SYSCON_BMAR		EP93XX_SYSCON_REG(0x54)
#define EP93XX_SYSCON_DEVICE_CONFIG	EP93XX_SYSCON_REG(0x80)
#define EP93XX_SYSCON_DEVICE_CONFIG_U3EN		(1<<24)
#define EP93XX_SYSCON_DEVICE_CONFIG_CRUNCH_ENABLE	(1<<23)
#define EP93XX_SYSCON_DEVICE_CONFIG_U2EN		(1<<20)
#define EP93XX_SYSCON_DEVICE_CONFIG_EXVC		(1<<19)
#define EP93XX_SYSCON_DEVICE_CONFIG_U1EN		(1<<18)
#define EP93XX_SYSCON_DEVICE_CONFIG_RASONP3		(1<<4)


#define EP93XX_SYSCON_SWLOCK		EP93XX_SYSCON_REG(0xc0)
#define EP93XX_SYSCON_VIDEO_CLOCK	EP93XX_SYSCON_REG(0x84)
#define EP93XX_SYSCON_VIDEO_CLOCK_VDIV_MASK         0x0000007f              
#define EP93XX_SYSCON_VIDEO_CLOCK_VDIV_SHIFT        0
#define EP93XX_SYSCON_VIDEO_CLOCK_PDIV_MASK         0x00000300
#define EP93XX_SYSCON_VIDEO_CLOCK_PDIV_SHIFT        8
#define EP93XX_SYSCON_VIDEO_CLOCK_PSEL              0x00002000
#define EP93XX_SYSCON_VIDEO_CLOCK_ESEL              0x00004000
#define EP93XX_SYSCON_VIDEO_CLOCK_VENA              0x00008000

#define EP93XX_WATCHDOG_BASE		(EP93XX_APB_VIRT_BASE + 0x00140000)


#endif
